"""Contains AI-Horde specific classes which are used across the ecosystem."""

from .settings import AIHordeClientSettings, AIHordeServerSettings, AIHordeWorkerSettings

__all__ = [
    "AIHordeClientSettings",
    "AIHordeServerSettings",
    "AIHordeWorkerSettings",
]
